You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ri...@apache.org on 2009/04/13 16:06:38 UTC

svn commit: r764475 - in /qpid/branches/0.5-fix/qpid: ./ java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java

Author: ritchiem
Date: Mon Apr 13 14:06:37 2009
New Revision: 764475

URL: http://svn.apache.org/viewvc?rev=764475&view=rev
Log:
QPID-1743: change maxMessageSize description to indicate it is in Bytes not KBytes, make size descriptions in other methods consistent
merged from trunk r755256

Modified:
    qpid/branches/0.5-fix/qpid/   (props changed)
    qpid/branches/0.5-fix/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java

Propchange: qpid/branches/0.5-fix/qpid/
------------------------------------------------------------------------------
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Apr 13 14:06:37 2009
@@ -1 +1 @@
-/qpid/trunk/qpid:742626,743015,743028-743029,743304,743306,743311,743357,744113,747363,747367,747369-747370,747376,747783,747868-747870,747875,748561,748591,748641,748680,748686,749149,749282,749285,749315,749340,749572,754934,754958
+/qpid/trunk/qpid:742626,743015,743028-743029,743304,743306,743311,743357,744113,747363,747367,747369-747370,747376,747783,747868-747870,747875,748561,748591,748641,748680,748686,749149,749282,749285,749315,749340,749572,754934,754958,755256

Modified: qpid/branches/0.5-fix/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
URL: http://svn.apache.org/viewvc/qpid/branches/0.5-fix/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java?rev=764475&r1=764474&r2=764475&view=diff
==============================================================================
--- qpid/branches/0.5-fix/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java (original)
+++ qpid/branches/0.5-fix/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java Mon Apr 13 14:06:37 2009
@@ -131,7 +131,7 @@
     void setMaximumMessageAge(Long age) throws IOException;
 
     /**
      * Returns the maximum size of a message (in kbytes) allowed to be accepted by the
      * ManagedQueue. This is useful in setting notifications or taking
      * appropriate action, if the size of the message received is more than
      * the allowed size.
@@ -142,12 +142,12 @@
     Long getMaximumMessageSize() throws IOException;
 
     /**
      * Sets the maximum size of the message (in kbytes) that is allowed to be
      * accepted by the Queue.
      * @param size  maximum size of message.
      * @throws IOException
      */
-    @MBeanAttribute(name="MaximumMessageSize", description="Threshold high value(KB) for a message size")
+    @MBeanAttribute(name="MaximumMessageSize", description="Threshold high value(Bytes) for a message size")
     void setMaximumMessageSize(Long size) throws IOException;
 
     /**
@@ -184,6 +184,62 @@
     @MBeanAttribute(name="MaximumQueueDepth", description="The threshold high value(Bytes) for Queue Depth")
     void setMaximumQueueDepth(Long value) throws IOException;
 
+    /**
+     * View the limit on the memory that this queue will utilise.
+     *
+     * Used by Flow to Disk.
+     *
+     * @return The maximum memory(B) that the queue will occuy.
+     */
+    public Long getMemoryUsageMaximum();
+
+    /**
+     * Place a limit on the memory that this queue will utilise.
+     *
+     * Used by Flow to Disk
+     *
+     * @param maximumMemoryUsage The new maximum memory(B) to be used by this queue
+     */
+    @MBeanAttribute(name="MemoryUsageMaximum", description="The maximum memory(Bytes) that the queue will occupy.")
+    public void setMemoryUsageMaximum(Long maximumMemoryUsage);
+
+    /**
+     * View the minimum amount of memory that has been defined for this queue.
+     *
+     * Used by Flow to Disk
+     *
+     * @return The minimum amount of queue data(B) that the queue will attempt to keep in memory
+     */
+    public Long getMemoryUsageMinimum();
+
+    /**
+     * Set the minimum amount of memory that has been defined for this queue.
+     *
+     * Used by Flow to Disk
+     *
+     * @param minimumMemoryUsage The new minimum memory(B) level to be used by this queue
+     */
+    @MBeanAttribute(name="MemoryUsageMinimum", description="The minimum memory(Bytes) that the queue will occupy.")
+    public void setMemoryUsageMinimum(Long minimumMemoryUsage);
+
+    /**
+     * View the amount of memory(B) that this queue is using.
+     *
+     * @return The current memory(B) usage of this queue.
+     */
+    @MBeanAttribute(name="MemoryUsageCurrent", description="The current amount of memory(Bytes) used by this queue.")
+    public Long getMemoryUsageCurrent();
+
+    /**
+     * When a queue exceeds its MemoryUsageMaximum value then the Queue will start flowing to disk.
+     *
+     * This boolean is used to show that change in state.
+     *
+     * @return true if the Queue is currently flowing to disk
+     */
+    @MBeanAttribute(name="isFlowed", description="true if the queue is currently flowing to disk.")
+    public boolean isFlowed();
+
 
 
     //********** Operations *****************//



---------------------------------------------------------------------
@@ -131,7 +131,7 @@
 
     /**
-     * Returns the maximum size of a message (in kbytes) allowed to be accepted by the
+     * Returns the maximum size of a message (in Bytes) allowed to be accepted by the
      * ManagedQueue. This is useful in setting notifications or taking
      * appropriate action, if the size of the message received is more than
@@ -142,12 +142,12 @@
 
     /**
-     * Sets the maximum size of the message (in kbytes) that is allowed to be
+     * Sets the maximum size of the message (in Bytes) that is allowed to be
      * accepted by the Queue.
      * @param size  maximum size of message.
Apache Qpid - AMQP Messaging Implementation
Project:      http://qpid.apache.org
Use/Interact: mailto:commits-subscribe@qpid.apache.org